CacheLayer

Struct CacheLayer 

pub struct CacheLayer<Req, K> { /* private fields */ }
A Tower Layer that applies response caching to a service.

This layer wraps a service with a Cache middleware that stores successful responses and returns cached values for subsequent requests with the same key.

Examples

use tower_resilience_cache::CacheLayer;
use tower::ServiceBuilder;
use std::time::Duration;

let cache_layer = CacheLayer::builder()
    .max_size(100)
    .ttl(Duration::from_secs(60))
    .key_extractor(|req: &String| req.clone())
    .build();

let service = ServiceBuilder::new()
    .layer(cache_layer)
    .service(my_service());

Implementations

Source

impl<Req, K> CacheLayer<Req, K>
where K: Hash + Eq + Clone + Send + 'static,

pub fn new(config: CacheConfig<Req, K>) -> Self

Creates a new CacheLayer with the given configuration.

pub fn builder() -> CacheConfigBuilder<Req, K>

Creates a new builder for configuring a cache layer.

Examples
use tower_resilience_cache::CacheLayer;
use std::time::Duration;

let layer = CacheLayer::builder()
    .max_size(100)
    .ttl(Duration::from_secs(60))
    .key_extractor(|req: &String| req.clone())
    .build();