pub struct CacheLayer<Req, K> { /* private fields */ }Expand description
A Tower Layer that applies response caching to a service.
This layer wraps a service with a Cache middleware that stores
successful responses and returns cached values for subsequent requests
with the same key.
Examples
use tower_resilience_cache::CacheConfig;
use tower::ServiceBuilder;
use std::time::Duration;
let cache_layer = CacheConfig::builder()
.max_size(100)
.ttl(Duration::from_secs(60))
.key_extractor(|req: &String| req.clone())
.build();
let service = ServiceBuilder::new()
.layer(cache_layer)
.service(my_service());Implementations
Sourceimpl<Req, K> CacheLayer<Req, K>
impl<Req, K> CacheLayer<Req, K>
Sourcepub fn new(config: CacheConfig<Req, K>) -> Self
pub fn new(config: CacheConfig<Req, K>) -> Self
Creates a new CacheLayer with the given configuration.